==> dev-builder-4.20.0.tgz: package/assets/entry-editor.js <==
/* eslint-disable */
import './public-path';
import { dirname, basename, extname } from 'path';
import * as packageJson from '@/package.json';
import { setPropManifestToWindow } from './utils';
import clone from 'clone';

window.__components = window.__components || [];
window.__localBlocks = [];
window.__blocks = [];
window.__blocksList = [];
window.__blocksGroups = [];
window.__blocksFilters = [];
window.__brandsList = [];
window.__componentsList = [];
window.__modulesList = [];
window.__componentsFileProps = {};
window.__installedComponents = {};
let blocksList = {};

if (
  process.env.CONTENT_TYPE === ContentTypes.EMAIL ||
  process.env.CONTENT_TYPE === ContentTypes.SITE ||
  process.env.CONTENT_TYPE === ContentTypes.MODULE ||
  process.env.CONTENT_TYPE === ContentTypes.EDETAILER ||
  process.env.CONTENT_TYPE === ContentTypes.MESSENGER_AD
) {

  if (process.env.BLOCKS_MANIFEST) {
    const manifest = require('./compound-manifest.js');

    setPropManifestToWindow(manifest.blockManifest, 'components', '__blocksList');
    setPropManifestToWindow(manifest.blockManifest, 'groups', '__blocksGroups');
    setPropManifestToWindow(manifest.blockManifest, 'filters', '__blocksFilters');
    setPropManifestToWindow(manifest.blockManifest, 'brands', '__brandsList');

    window.__blocksList
      .forEach((block) => {
        const requiredBlock = manifest.requiredBlocks[block.id];
        const blockModule = requiredBlock.default || requiredBlock;

        if (blockModule.methods) {
          replaceMethods(blockModule);
        }

        const clonedBlock = clone(blockModule, { includeNonEnumerable: true });

        window.__blocks.push(clonedBlock);
      });
  }
  if (process.env.BLOCKS_THEMES_MANIFEST) {
    const manifest = require('./compound-manifest.js');
    window.__blocksThemes = manifest.blockThemesManifest.themes;
	}
  if (process.env.COMPONENTS_THEMES_MANIFEST) {
    const manifest = require('./compound-manifest.js');

    window.__componentsThemes = manifest.componentsThemesManifest.themes;
  }
  if (process.env.COMPONENTS_MANIFEST) {
    const manifest = require('./compound-manifest.js');

    window.__componentsList = window.__componentsList.concat(manifest.componentManifest.components);
  }
  if (process.env.MODULES_MANIFEST) {
    const modulesManifest = require(process.env.MODULES_MANIFEST);
    window.__modulesList = window.__modulesList.concat(modulesManifest.components || []);
  }
  if (process.env.COMPONENT_FILE_PROPS) {
    window.__componentsFileProps = process.env.COMPONENT_FILE_PROPS;
  }
  fillWindowBlocks();

  if (window.__modulesList) {
    window.__modulesList.forEach(requireBlock);
  }
} else if (
  process.env.CONTENT_TYPE === ContentTypes.EDETAILER ||
  process.env.CONTENT_TYPE === ContentTypes.SURVEY
) {
  if (process.env.COMPONENTS_MANIFEST) {
    const manifest = require('./compound-manifest.js');

    window.__componentsList = window.__componentsList.concat(manifest.componentManifest.components);
  }

  const structure = require('@/structure.json');
  Object.keys(structure.slides).forEach((slideId) => {
    const slideObj = structure.slides[slideId];
    const normalizedTemplatePath = basename(dirname(slideObj.template));
    const slideModule = __non_webpack_require__(`./slides/${normalizedTemplatePath}/index.vue`);
    const slide = slideModule.default || slideModule;
    slide.slideId = slideId;
    window.__components.push(slide);
  });
} else if ( process.env.CONTENT_TYPE === ContentTypes.JOURNEY ) {
  if (process.env.COMPONENTS_MANIFEST) {
    const manifest = require('./compound-manifest.js');

    window.__componentsList = window.__componentsList.concat(manifest.componentManifest.components);
  }
}

if (packageJson) {
  window.__installedComponents = getInstalledComponents();
}

function requireBlock({ id }) {
  /marker-blocks-start/
  const blockModule = require(`${process.env.LIBRARY_BLOCKS}/${id}/index.vue`);
  const block = blockModule.default || blockModule;
  /marker-blocks-end/

  if (block.methods) {
    replaceMethods(block);
  }

  window.__blocks.push(block);
}

function replaceMethods(block) {
  Object.keys(block.methods).forEach((method) => {
    const methodFunction = block.methods[method];
    block.methods[method] = function(...args) {
      console.error(`Methods are not supported in Block content type`);
      return methodFunction.call(this, args);
    };
  });
}

function getInstalledComponents() {
  return Object.keys(packageJson.dependencies || {}).reduce(function(data, key) {
    data[key] = {
      path: './node_modules/' + key,
    };
    return data;
  }, {});
}

function fillWindowBlocks(){
  /marker-components-start/
  const blocksContext = require.context(process.env.LOCAL_BLOCKS, true, /index\.vue$/);

  blocksContext.keys().forEach((filePath) => {
    const blockModule = blocksContext(filePath);
    const block = blockModule.default || blockModule;
    window.__components.push(block);
  });
  /marker-components-end/
}

==> dev-builder-5.1.2.tgz: package/assets/entry-editor.js <==
/* eslint-disable */
import './public-path';
import { dirname, basename, extname } from 'path';
import * as packageJson from '@/package.json';
import { setPropManifestToWindow } from './utils';
import clone from 'clone';

window.__components = window.__components || [];
window.__localBlocks = [];
window.__blocks = [];
window.__blocksList = [];
window.__blocksGroups = [];
window.__blocksFilters = [];
window.__brandsList = [];
window.__componentsList = [];
window.__modulesList = [];
window.__componentsFileProps = {};
window.__installedComponents = {};
let blocksList = {};

if (
  process.env.CONTENT_TYPE === ContentTypes.EMAIL ||
  process.env.CONTENT_TYPE === ContentTypes.SITE ||
  process.env.CONTENT_TYPE === ContentTypes.MODULE ||
  process.env.CONTENT_TYPE === ContentTypes.EDETAILER ||
  process.env.CONTENT_TYPE === ContentTypes.MESSENGER_AD ||
  process.env.CONTENT_TYPE === ContentTypes.BANNER
) {

  if (process.env.BLOCKS_MANIFEST) {
    const manifest = require('./compound-manifest.js');

    setPropManifestToWindow(manifest.blockManifest, 'components', '__blocksList');
    setPropManifestToWindow(manifest.blockManifest, 'groups', '__blocksGroups');
    setPropManifestToWindow(manifest.blockManifest, 'filters', '__blocksFilters');
    setPropManifestToWindow(manifest.blockManifest, 'brands', '__brandsList');

    window.__blocksList
      .forEach((block) => {
        const requiredBlock = manifest.requiredBlocks[block.id];
        const blockModule = requiredBlock.default || requiredBlock;

        if (blockModule.methods) {
          replaceMethods(blockModule);
        }

        const clonedBlock = clone(blockModule, { includeNonEnumerable: true });

        window.__blocks.push(clonedBlock);
      });
  }
  if (process.env.BLOCKS_THEMES_MANIFEST) {
    const manifest = require('./compound-manifest.js');
    window.__blocksThemes = manifest.blockThemesManifest.themes;
	}
  if (process.env.COMPONENTS_THEMES_MANIFEST) {
    const manifest = require('./compound-manifest.js');

    window.__componentsThemes = manifest.componentsThemesManifest.themes;
  }
  if (process.env.COMPONENTS_MANIFEST) {
    const manifest = require('./compound-manifest.js');

    window.__componentsList = window.__componentsList.concat(manifest.componentManifest.components);
  }
  if (process.env.MODULES_MANIFEST) {
    const modulesManifest = require(process.env.MODULES_MANIFEST);
    window.__modulesList = window.__modulesList.concat(modulesManifest.components || []);
  }
  if (process.env.COMPONENT_FILE_PROPS) {
    window.__componentsFileProps = process.env.COMPONENT_FILE_PROPS;
  }
  fillWindowBlocks();

  if (window.__modulesList) {
    window.__modulesList.forEach(requireBlock);
  }
} else if (
  process.env.CONTENT_TYPE === ContentTypes.EDETAILER ||
  process.env.CONTENT_TYPE === ContentTypes.SURVEY
) {
  if (process.env.COMPONENTS_MANIFEST) {
    const manifest = require('./compound-manifest.js');

    window.__componentsList = window.__componentsList.concat(manifest.componentManifest.components);
  }

  const structure = require('@/structure.json');
  Object.keys(structure.slides).forEach((slideId) => {
    const slideObj = structure.slides[slideId];
    const normalizedTemplatePath = basename(dirname(slideObj.template));
    const slideModule = __non_webpack_require__(`./slides/${normalizedTemplatePath}/index.vue`);
    const slide = slideModule.default || slideModule;
    slide.slideId = slideId;
    window.__components.push(slide);
  });
} else if ( process.env.CONTENT_TYPE === ContentTypes.JOURNEY ) {
  if (process.env.COMPONENTS_MANIFEST) {
    const manifest = require('./compound-manifest.js');

    window.__componentsList = window.__componentsList.concat(manifest.componentManifest.components);
  }
}

if (packageJson) {
  window.__installedComponents = getInstalledComponents();
}

function requireBlock({ id }) {
  /marker-blocks-start/
  const blockModule = require(`${process.env.LIBRARY_BLOCKS}/${id}/index.vue`);
  const block = blockModule.default || blockModule;
  /marker-blocks-end/

  if (block.methods) {
    replaceMethods(block);
  }

  window.__blocks.push(block);
}

function replaceMethods(block) {
  Object.keys(block.methods).forEach((method) => {
    const methodFunction = block.methods[method];
    block.methods[method] = function(...args) {
      console.error(`Methods are not supported in Block content type`);
      return methodFunction.call(this, args);
    };
  });
}

function getInstalledComponents() {
  return Object.keys(packageJson.dependencies || {}).reduce(function(data, key) {
    data[key] = {
      path: './node_modules/' + key,
    };
    return data;
  }, {});
}

function fillWindowBlocks(){
  /marker-components-start/
  const blocksContext = require.context(process.env.LOCAL_BLOCKS, true, /index\.vue$/);

  blocksContext.keys().forEach((filePath) => {
    const blockModule = blocksContext(filePath);
    const block = blockModule.default || blockModule;
    window.__components.push(block);
  });
  /marker-components-end/
}
